@@ -56,10 +56,10 @@ class TestMicrosoftTranslator(object):
 
     def test_get_languages_for_translate(self):
         assert_equal(
-            ('Microsoft', ['ar', 'bg', 'zh-CHS', 'zh-CHT', 'cs', 'da',
-                'nl', 'en', 'et', 'fi', 'fr', 'de', 'el', 'ht', 'he', 'hu',
-                'id', 'it', 'ja', 'ko', 'lv', 'lt', 'no', 'pl', 'pt', 'ro',
-                'ru', 'sk', 'sl', 'es', 'sv', 'th', 'tr', 'uk', 'vi']),
+            ('Microsoft', ['ar', 'bg', 'ca', 'zh-CHS', 'zh-CHT', 'cs', 'da',
+                'nl', 'en', 'et', 'fi', 'fr', 'de', 'el', 'ht', 'he', 'hi',
+                'hu', 'id', 'it', 'ja', 'ko', 'lv', 'lt', 'no', 'pl', 'pt',
+                'ro', 'ru', 'sk', 'sl', 'es', 'sv', 'th', 'tr', 'uk', 'vi']),
             self.t.get_languages_for_translate())
 
     def test_translate(self):
